@@ -64,11 +64,11 @@ extremaltfull <- function(data, coord, start, cov.mod = "whitmat", ...,
 
     ##And define the "body" of the function as the number of parameters
     ##to estimate depends on n.site
-    body(nplk) <- parse(text = paste("-.C('extremaltfull', as.integer(cov.mod.num), as.double(data), as.double(dist), as.integer(n.site), as.integer(n.obs), as.integer(dist.dim), as.integer(weighted), as.double(weights),",
+    body(nplk) <- parse(text = paste("-.C(C_extremaltfull, as.integer(cov.mod.num), as.double(data), as.double(dist), as.integer(n.site), as.integer(n.obs), as.integer(dist.dim), as.integer(weighted), as.double(weights),",
                         paste("as.double(c(", paste(loc.names, collapse = ","), ")), "),
                         paste("as.double(c(", paste(scale.names, collapse = ","), ")), "),
                         paste("as.double(c(", paste(shape.names, collapse = ","), ")), "),
-                        "as.double(nugget), as.double(range), as.double(smooth), as.double(smooth2), as.double(DoF), fit.marge, dns = double(1), PACKAGE = 'SpatialExtremes', NAOK = TRUE)$dns"))
+                        "as.double(nugget), as.double(range), as.double(smooth), as.double(smooth2), as.double(DoF), fit.marge, dns = double(1), NAOK = TRUE)$dns"))
 
     fixed.param <- list(...)[names(list(...)) %in% param]
 
@@ -283,19 +283,19 @@ extremaltfull <- function(data, coord, start, cov.mod = "whitmat", ...,
         rho <- cov.fun(h)
         rho <- matrix(rho, 2 * n.sim, n.site, byrow = TRUE)
         b <- sqrt((1 - rho^2) / (param["DoF"] + 1))
-        
+
         normCst <- sqrt(pi) * 2^(-(param["DoF"] - 2)/2) / gamma(0.5 * (param["DoF"] + 1))
         Y <- rgp(n.sim, h, cov.mod, nugget = param["nugget"], sill = 1 - param["nugget"],
                  range = param["range"], smooth = param["smooth"])
         Y <- normCst * rbind(pmax(Y,0), pmax(-Y, 0))^param["DoF"]##antithetic
         dummy <- 1 / (1/Y[,1] * pt(-rho / b + (Y / Y[,1])^(1/param["DoF"]) / b, param["DoF"] + 1) +
                           1/Y * pt(-rho / b + (Y / Y[,1])^(-1/param["DoF"]) / b, param["DoF"] + 1))
-        
+
         dummy <- replace(dummy, is.na(dummy), 0)
         dummy[,1] <- 1 ## Fix conflict in NaN handling at the origin
         colMeans(dummy)
     }
-    
+
     fitted <- list(fitted.values = opt$par, std.err = std.err,
                    var.cov = var.cov, param = param, cov.fun = cov.fun, fixed = unlist(fixed.param),
                    deviance = 2*opt$value, corr = corr.mat, convergence = opt$convergence,
@@ -477,7 +477,7 @@ extremaltform <- function(data, coord, cov.mod, loc.form, scale.form, shape.form
     ##And define the "body" of the function as the number of parameters
     ##to estimate depends on n.site
 
-    body(nplk) <- parse(text = paste("-.C('extremaltdsgnmat', as.integer(cov.mod.num),
+    body(nplk) <- parse(text = paste("-.C(C_extremaltdsgnmat, as.integer(cov.mod.num),
 as.double(data), as.double(dist), as.integer(n.site), as.integer(n.obs), as.integer(dist.dim),
 as.integer(weighted), as.double(weights), as.double(loc.dsgn.mat), as.double(loc.pen.mat),
 as.integer(n.loccoeff), as.integer(n.pparloc), as.double(loc.penalty), as.double(scale.dsgn.mat),
@@ -497,7 +497,7 @@ as.double(temp.penalty.shape),",
                         paste("as.double(c(", paste(temp.names.scale, collapse = ","), ")), "),
                         paste("as.double(c(", paste(temp.names.shape, collapse = ","), ")), "),
                         "as.double(nugget), as.double(range), as.double(smooth), as.double(smooth2),
-as.double(DoF), dns = double(1), PACKAGE = 'SpatialExtremes', NAOK = TRUE)$dns"))
+as.double(DoF), dns = double(1), NAOK = TRUE)$dns"))
 
     ##Define the formal arguments of the function
     form.nplk <- NULL
@@ -716,14 +716,14 @@ as.double(DoF), dns = double(1), PACKAGE = 'SpatialExtremes', NAOK = TRUE)$dns")
         rho <- cov.fun(h)
         rho <- matrix(rho, 2 * n.sim, n.site, byrow = TRUE)
         b <- sqrt((1 - rho^2) / (param["DoF"] + 1))
-        
+
         normCst <- sqrt(pi) * 2^(-(param["DoF"] - 2)/2) / gamma(0.5 * (param["DoF"] + 1))
         Y <- rgp(n.sim, h, cov.mod, nugget = param["nugget"], sill = 1 - param["nugget"],
                  range = param["range"], smooth = param["smooth"])
         Y <- normCst * rbind(pmax(Y,0), pmax(-Y, 0))^param["DoF"]##antithetic
         dummy <- 1 / (1/Y[,1] * pt(-rho / b + (Y / Y[,1])^(1/param["DoF"]) / b, param["DoF"] + 1) +
                           1/Y * pt(-rho / b + (Y / Y[,1])^(-1/param["DoF"]) / b, param["DoF"] + 1))
-        
+
         dummy <- replace(dummy, is.na(dummy), 0)
         dummy[,1] <- 1 ## Fix conflict in NaN handling at the origin
         colMeans(dummy)
